==> go.php?file=PhoenixStyle5.401.zip: PhoenixStyleMod_Panda_tier3/GeneralNazgrim.lua <==
﻿psbossfilep68=1




function pscmrbossREPORTp681(wipe,try,reset,checkforwipe)
if reset==nil then
if checkforwipe==nil or (checkforwipe and pswasonbossp68 and pswasonbossp68==1) then

	if pswasonbossp68==1 then
		pssetcrossbeforereport1=GetTime()

		if psraidoptionson[2][6][8][1]==1 then
			strochkavezcrash=psiccdmgfrom.." |s4id134539|id ("..psmainmtotal.."): "
			reportafterboitwotab(psraidchats3[psraidoptionschat[2][6][8][1]], true, vezaxname, vezaxcrash, 1)
		end



	end
	if pswasonbossp68==1 or (pswasonbossp68==2 and try==nil) then

		psiccsavinginf(psbossnames[2][6][8], try, pswasonbossp68)

		strochkavezcrash=psiccdmgfrom.." |s4id134539|id ("..psmainmtotal.."): "
		reportafterboitwotab("raid", true, vezaxname, vezaxcrash, nil, nil,0,1)


		psiccrefsvin()

	end




	if wipe then
		pswasonbossp68=2
		pscheckbossincombatmcr_p3=GetTime()+1
	end
end
end
end


function pscmrbossRESETp681(wipe,try,reset,checkforwipe)
if reset or wipe==nil then
pswasonbossp68=nil


table.wipe(vezaxname)
table.wipe(vezaxcrash)
table.wipe(vezaxname2)
table.wipe(vezaxcrash2)


end
end



function pscombatlogbossp68(arg1, arg2, hideCaster, guid1, name1, flag1, new1, guid2, name2, flag2, new2, spellid, spellname, arg11,arg12,arg13,arg14,arg15)



-- МАКЕТ, НЕ ЗАДЕЙСТВОВАННЫЙ

if arg2=="SPELL_DAMAGE" and spellid==134539 then
  if pswasonbossp68==nil then
    pswasonbossp68=1
  end
  psunitisplayer(guid2,name2)
  if psunitplayertrue then

    pscheckwipe1()
    if pswipetrue and pswasonbossp68~=2 then
      psiccwipereport_p3("wipe", "try")
    end
    addtotwotables1(name2)
    vezaxsort1()
    local tt2=", "..psdamageceil(arg12)
      if arg13>=0 then
        tt2=", "..psdamageceil(arg12-arg13).." |cffff0000("..psoverkill..": "..psdamageceil(arg13)..")|r"
      end
    pscaststartinfo(0,spellname..": "..psaddcolortxt(1,name2)..name2..psaddcolortxt(2,name2)..tt2, -1, "id1", 1, "|s4id"..spellid.."|id - "..psinfo,psbossnames[2][6][8],2)
  end
end



--сбивание кастов
if arg2=="SPELL_CAST_START" and spellid==143432 then
pscheckrunningbossid(guid1)
pscaststartinfo(spellid,spellname..": %s.", 2, guid1, 91, "|s4id"..spellid.."|id - "..pseventsincomb2,psbossnames[2][6][8])
end
if arg2=="SPELL_CAST_START" and spellid==143431 then
pscheckrunningbossid(guid1)
pscaststartinfo(spellid,spellname..": %s.", 2, guid1, 92, "|s4id"..spellid.."|id - "..pseventsincomb2,psbossnames[2][6][8])
end
if arg2=="SPELL_CAST_START" and spellid==143473 then
pscheckrunningbossid(guid1)
pscaststartinfo(spellid,spellname..": %s.", 2, guid1, 93, "|s4id"..spellid.."|id - "..pseventsincomb2,psbossnames[2][6][8])
end



end

==> go.php?file=PhoenixStyle5.404.zip: PhoenixStyleMod_Panda_tier3/GeneralNazgrim.lua <==
﻿psbossfilep68=1




function pscmrbossREPORTp681(wipe,try,reset,checkforwipe)
if reset==nil then
if checkforwipe==nil or (checkforwipe and pswasonbossp68 and pswasonbossp68==1) then

	if pswasonbossp68==1 then
		pssetcrossbeforereport1=GetTime()

		if psraidoptionson[2][6][8][1]==1 then
			strochkavezcrash=psiccdmgfrom.." |s4id143712|id ("..psmainmtotal.."): "
			reportafterboitwotab(psraidchats3[psraidoptionschat[2][6][8][1]], true, vezaxname, vezaxcrash, 1)
		end
		if psraidoptionson[2][6][8][2]==1 then
			strochkavezcrash=psiccdmgfrom.." |s4id143873|id ("..psmainmtotal.."): "
			reportafterboitwotab(psraidchats3[psraidoptionschat[2][6][8][2]], true, vezaxname2, vezaxcrash2, 1)
		end


	end
	if pswasonbossp68==1 or (pswasonbossp68==2 and try==nil) then

		psiccsavinginf(psbossnames[2][6][8], try, pswasonbossp68)

		strochkavezcrash=psiccdmgfrom.." |s4id143712|id ("..psmainmtotal.."): "
		reportafterboitwotab("raid", true, vezaxname, vezaxcrash, nil, nil,0,1)
		strochkavezcrash=psiccdmgfrom.." |s4id143873|id ("..psmainmtotal.."): "
		reportafterboitwotab("raid", true, vezaxname2, vezaxcrash2, nil, nil,0,1)

		psiccrefsvin()

	end




	if wipe then
		pswasonbossp68=2
		pscheckbossincombatmcr_p3=GetTime()+1
	end
end
end
end


function pscmrbossRESETp681(wipe,try,reset,checkforwipe)
if reset or wipe==nil then
pswasonbossp68=nil


table.wipe(vezaxname)
table.wipe(vezaxcrash)
table.wipe(vezaxname2)
table.wipe(vezaxcrash2)


end
end



function pscombatlogbossp68(arg1, arg2, hideCaster, guid1, name1, flag1, new1, guid2, name2, flag2, new2, spellid, spellname, arg11,arg12,arg13,arg14,arg15)



if arg2=="SPELL_DAMAGE" and spellid==143712 then
  if pswasonbossp68==nil then
    pswasonbossp68=1
  end
  psunitisplayer(guid2,name2)
  if psunitplayertrue then

    pscheckwipe1()
    if pswipetrue and pswasonbossp68~=2 then
      psiccwipereport_p3("wipe", "try")
    end
    addtotwotables1(name2)
    vezaxsort1()
    local tt2=", "..psdamageceil(arg12)
      if arg13>=0 then
        tt2=", "..psdamageceil(arg12-arg13).." |cffff0000("..psoverkill..": "..psdamageceil(arg13)..")|r"
      end
    pscaststartinfo(0,spellname..": "..psaddcolortxt(1,name2)..name2..psaddcolortxt(2,name2)..tt2, -1, "id1", 1, "|s4id"..spellid.."|id - "..psinfo,psbossnames[2][6][8],2)
  end
end


if arg2=="SPELL_DAMAGE" and spellid==143873 then
  if pswasonbossp68==nil then
    pswasonbossp68=1
  end
  psunitisplayer(guid2,name2)
  if psunitplayertrue then

    pscheckwipe1()
    if pswipetrue and pswasonbossp68~=2 then
      psiccwipereport_p3("wipe", "try")
    end
    addtotwotables2(name2)
    vezaxsort2()
    local tt2=", "..psdamageceil(arg12)
      if arg13>=0 then
        tt2=", "..psdamageceil(arg12-arg13).." |cffff0000("..psoverkill..": "..psdamageceil(arg13)..")|r"
      end
    pscaststartinfo(0,spellname..": "..psaddcolortxt(1,name2)..name2..psaddcolortxt(2,name2)..tt2, -1, "id1", 2, "|s4id"..spellid.."|id - "..psinfo,psbossnames[2][6][8],2)
  end
end



--сбивание кастов
if arg2=="SPELL_CAST_START" and spellid==143432 then
pscheckrunningbossid(guid1)
pscaststartinfo(spellid,spellname..": %s.", 2, guid1, 91, "|s4id"..spellid.."|id - "..pseventsincomb2,psbossnames[2][6][8])
end
if arg2=="SPELL_CAST_START" and spellid==143431 then
pscheckrunningbossid(guid1)
pscaststartinfo(spellid,spellname..": %s.", 2, guid1, 92, "|s4id"..spellid.."|id - "..pseventsincomb2,psbossnames[2][6][8])
end
if arg2=="SPELL_CAST_START" and spellid==143473 then
pscheckrunningbossid(guid1)
pscaststartinfo(spellid,spellname..": %s.", 2, guid1, 93, "|s4id"..spellid.."|id - "..pseventsincomb2,psbossnames[2][6][8])
end


end
